<?php

namespace Island\Island\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Island\Island\Http\Requests\IslandsRequest;
use Island\Island\Models\Islands;

/**
 * Admin web controller class.
 */
class IslandsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for islands.
     *
     * @param Model   $islands
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(IslandsRequest $request, Islands $islands, $step)
    {

        try {

            $islands->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('island::islands.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/islands/islands/' . $islands->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/islands/islands/' . $islands->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for islands.
     *
     * @param Model   $islands
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Islands $islands, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $islands->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('island::islands.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('island::admin.islands.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('island::admin.islands.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('island::admin.islands.message', $data)->render();

        }

    }
}
