<?php

namespace Island\Island\Policies;

use Litepie\User\Contracts\UserPolicy;
use Island\Island\Models\Islands;

class IslandsPolicy
{

    /**
     * Determine if the given user can view the islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function view(UserPolicy $user, Islands $islands)
    {
        if ($user->canDo('island.islands.view') && $user->isAdmin()) {
            return true;
        }

        return $islands->user_id == user_id() && $islands->user_type == user_type();
    }

    /**
     * Determine if the given user can create a islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('island.islands.create');
    }

    /**
     * Determine if the given user can update the given islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function update(UserPolicy $user, Islands $islands)
    {
        if ($user->canDo('island.islands.edit') && $user->isAdmin()) {
            return true;
        }

        return $islands->user_id == user_id() && $islands->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Islands $islands)
    {
        return $islands->user_id == user_id() && $islands->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Islands $islands)
    {
        if ($user->canDo('island.islands.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given islands.
     *
     * @param UserPolicy $user
     * @param Islands $islands
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Islands $islands)
    {
        if ($user->canDo('island.islands.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
