<?php

namespace Island\Island\Providers;

use Illuminate\Support\ServiceProvider;

class IslandServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'island');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'island');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerIsland();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerIsland()
    {
        $this->app->bind('island', function($app) {
            return new Island($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Island', 'Lavalite\Island\Facades\Island');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('island.island', function ($app) {
            return $this->app->make('Island\Island\Island');
        });

                // Bind Islands to repository
        $this->app->bind(
            'Island\Island\Interfaces\IslandsRepositoryInterface',
            \Island\Island\Repositories\Eloquent\IslandsRepository::class
        );

        $this->app->register(\Island\Island\Providers\AuthServiceProvider::class);
                $this->app->register(\Island\Island\Providers\EventServiceProvider::class);
        
        $this->app->register(\Island\Island\Providers\RouteServiceProvider::class);
                $this->app->register(\Island\Island\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and island's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/island.php', 'island'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeIsland::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['island.island'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('island/island.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/island')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/island')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
