<?php

namespace Island\Island\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Island\Island\Models\Islands;

class IslandsAction
{
    /**
     * Perform the complete action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */
    public function complete(Islands $islands)
    {
        try {
            $islands->status = 'complete';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */public function verify(Islands $islands)
    {
        try {
            $islands->status = 'verify';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */public function approve(Islands $islands)
    {
        try {
            $islands->status = 'approve';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */public function publish(Islands $islands)
    {
        try {
            $islands->status = 'publish';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */
    public function archive(Islands $islands)
    {
        try {
            $islands->status = 'archive';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Islands $islands
     *
     * @return Islands
     */
    public function unpublish(Islands $islands)
    {
        try {
            $islands->status = 'unpublish';
            return $islands->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
