<?php

namespace Island\Island\Workflow;

use Island\Island\Models\Islands;
use Validator;

class IslandsValidator
{

    /**
     * Determine if the given islands is valid for complete status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function complete(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given islands is valid for verify status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function verify(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given islands is valid for approve status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function approve(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given islands is valid for publish status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function publish(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given islands is valid for archive status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function archive(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given islands is valid for unpublish status.
     *
     * @param Islands $islands
     *
     * @return bool / Validator
     */
    public function unpublish(Islands $islands)
    {
        return Validator::make($islands->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
